@@ -1,32 +1,44 @@
+"""
+Authentication
+--------------
+
+User account plugins and authentication.
+"""
+
+from . import model
+from ..content.api.authentication import authenticate_token as authenticate_cms_token
+from .interfaces import IClientSkinLayer
+from AccessControl import ClassSecurityInfo
+from Acquisition import aq_parent
+from App.class_init import InitializeClass
+from euphorie.content.api.interfaces import ICMSAPISkinLayer
+from Products.PageTemplates.PageTemplateFile import PageTemplateFile
+from Products.PluggableAuthService.interfaces.plugins import IAuthenticationPlugin
+from Products.PluggableAuthService.interfaces.plugins import IChallengePlugin
+from Products.PluggableAuthService.interfaces.plugins import IExtractionPlugin
+from Products.PluggableAuthService.interfaces.plugins import IUserEnumerationPlugin
+from Products.PluggableAuthService.interfaces.plugins import IUserFactoryPlugin
+from Products.PluggableAuthService.plugins.BasePlugin import BasePlugin
+from Products.PluggableAuthService.utils import classImplements
+from z3c.saconfig import Session
+from zope.publisher.interfaces.browser import IBrowserView
+
 import logging
+import six
+import sqlalchemy.exc
 import traceback
 import urllib
-import sqlalchemy.exc
-from z3c.saconfig import Session
-from Acquisition import aq_parent
-from AccessControl import ClassSecurityInfo
-from App.class_init import InitializeClass
-from zope.publisher.interfaces.browser import IBrowserView
-from Products.PluggableAuthService.utils import classImplements
-from Products.PluggableAuthService.plugins.BasePlugin import BasePlugin
-from Products.PluggableAuthService.interfaces.plugins \
-        import IAuthenticationPlugin
-from Products.PluggableAuthService.interfaces.plugins import IExtractionPlugin
-from Products.PluggableAuthService.interfaces.plugins import IChallengePlugin
-from Products.PluggableAuthService.interfaces.plugins \
-        import IUserEnumerationPlugin
-from Products.PluggableAuthService.interfaces.plugins import IUserFactoryPlugin
-from Products.PageTemplates.PageTemplateFile import PageTemplateFile
-from .interfaces import IClientSkinLayer
-from . import model
-from .api.authentication import authenticate_token as authenticate_client_token
-from ..content.api.authentication \
-        import authenticate_token as authenticate_cms_token
 
 
 log = logging.getLogger(__name__)
 
 
+class NotImplementedError(Exception):
+
+    def __init__(self, message):
+        self.message = message
+
+
 def graceful_recovery(default=None, log_args=True):
     """Decorator to safely use SQLAlchemy in PAS plugins. This decorator
     makes sure SQL exceptions are caught and logged.
@@ -38,7 +50,7 @@ def graceful_recovery(default=None, log_args=True):
         def wrapper(*args, **kwargs):
             try:
                 value = func(*args, **kwargs)
-            except sqlalchemy.exc.SQLAlchemyError, e:
+            except sqlalchemy.exc.SQLAlchemyError as e:
                 if log_args is False:
                     args = ()
                     kwargs = {}
@@ -90,27 +102,21 @@ class EuphorieAccountPlugin(BasePlugin):
         self._setId(id)
         self.title = title
 
-    #
-    # IExtractionPlugin implementation
-    #
     def extractCredentials(self, request):
+        """IExtractionPlugin implementation"""
         token = request.getHeader('X-Euphorie-Token')
         if token:
             return {'api-token': token}
         else:
             return {}
 
-    #
-    # IAuthenticationPlugin implementation
-    #
     @security.private
     def _authenticate_token(self, credentials):
+        """IAuthenticationPlugin implementation"""
         token = credentials.get('api-token')
         if not token:
             return None
-        account = authenticate_client_token(token)
-        if account is None:
-            account = authenticate_cms_token(self, token)
+        account = authenticate_cms_token(self, token)
         return account
 
     @security.private
@@ -123,35 +129,53 @@ class EuphorieAccountPlugin(BasePlugin):
         else:
             return None
 
+    @security.private
+    def _get_survey_session(self):
+        for parent in self.REQUEST.other['PARENTS']:
+            if isinstance(parent, model.SurveySession):
+                return parent
+        else:
+            return None
+
     @security.private
     @graceful_recovery(log_args=False)
     def authenticateCredentials(self, credentials):
+        if not (
+            IClientSkinLayer.providedBy(self.REQUEST) or
+            ICMSAPISkinLayer.providedBy(self.REQUEST)
+        ):
+            return None
         uid_and_login = self._authenticate_login(credentials)
         if uid_and_login is None:
             uid_and_login = self._authenticate_token(credentials)
         if uid_and_login is not None:
+            session = self._get_survey_session()
+            if session is not None:
+                # Verify if current session matches the user. This prevents
+                # a cookie hijack attack.
+                if str(session.account_id) != uid_and_login[0]:
+                    return None
             return uid_and_login
         else:
             return None
 
-    #
-    # IUserFactoryPlugin implementation
     @graceful_recovery()
     def createUser(self, user_id, name):
+        """IUserFactoryPlugin implementation"""
         try:
             user_id = int(user_id)
         except (TypeError, ValueError):
             return None
         return Session().query(model.Account).get(user_id)
 
-    #
-    # IUserEnumerationPlugin implementation
-    #
     @graceful_recovery()
     def enumerateUsers(self, id=None, login=None, exact_match=False,
                        sort_by=None, max_results=None, **kw):
+        """IUserEnumerationPlugin implementation"""
         if not exact_match:
             return []
+        if not IClientSkinLayer.providedBy(self.REQUEST):
+            return []
 
         query = Session().query(model.Account)
         if id is not None:
@@ -166,10 +190,31 @@ class EuphorieAccountPlugin(BasePlugin):
             return [{'id': str(account.id), 'login': account.loginname}]
         return []
 
-    #
-    # IChallengePlugin implementation
-    #
+    def updateUser(self, user_id, login_name ):
+        """ Changes the user's username. New method available since Plone 4.3.
+            Euphorie doesn't support this.
+
+        :returns: False
+        """
+        return False
+
+    def updateEveryLoginName(self, quit_on_first_error=True):
+        """Update login names of all users to their canonical value.
+
+        This should be done after changing the login_transform
+        property of PAS.
+
+        You can set quit_on_first_error to False to report all errors
+        before quitting with an error.  This can be useful if you want
+        to know how many problems there are, if any.
+
+        :raises: NotImplementedError
+        """
+        raise NotImplementedError(
+                "updateEveryLoginName method is not implemented by Euphorie")
+
     def challenge(self, request, response):
+        """IChallengePlugin implementation"""
         if not IClientSkinLayer.providedBy(request):
             return False
 
@@ -180,7 +225,13 @@ class EuphorieAccountPlugin(BasePlugin):
                 query = "?" + query
             current_url += query
 
-        context = request.PUBLISHED
+        context = request.get('PUBLISHED')
+        if not context:
+            log.error(
+                'Refusing to authenticate because no context has been found in %r',  # noqa: E501
+                request,
+            )
+            return False
         if IBrowserView.providedBy(context):
             context = aq_parent(context)
 
@@ -202,12 +253,18 @@ def authenticate(login, password):
     """
     if not login or not password:
         return None
+    if isinstance(password, six.text_type):
+        password = password.encode('utf8')
 
     login = login.lower()
-    account = Session().query(model.Account)\
-            .filter(model.Account.loginname == login)\
-            .filter(model.Account.password == password).first()
-    return account
+    accounts = (
+        Session()
+        .query(model.Account)
+        .filter(model.Account.loginname == login)
+    )
+    for account in accounts:
+        if account.verify_password(password):
+            return account
 
 
 classImplements(
