@@ -1,26 +1,44 @@
-from euphorie.deployment.tests.functional import EuphorieTestCase
-from plone.dexterity.utils import createContentInContainer
+# coding=utf-8
 from euphorie.client import publish
+from euphorie.testing import EuphorieFunctionalTestCase
+from plone.dexterity.utils import createContentInContainer
 
 
-class PublishTests(EuphorieTestCase):
+class PublishTests(EuphorieFunctionalTestCase):
+
     def createSectorSurvey(self):
         self.loginAsPortalOwner()
         self.sectors = self.portal.sectors
-        createContentInContainer(self.sectors.nl, "euphorie.sector",
-                checkConstraints=False, title=u"dining")
+        createContentInContainer(
+            self.sectors.nl,
+            "euphorie.sector",
+            checkConstraints=False,
+            title=u"dining"
+        )
         self.sector = self.sectors.nl.dining
 
-        createContentInContainer(self.sector, "euphorie.surveygroup",
-                checkConstraints=False, title=u"Restaurants")
+        createContentInContainer(
+            self.sector,
+            "euphorie.surveygroup",
+            checkConstraints=False,
+            title=u"Restaurants"
+        )
         self.surveygroup = self.sector.restaurants
 
-        createContentInContainer(self.surveygroup, "euphorie.survey",
-                checkConstraints=False, title=u"Survey")
+        createContentInContainer(
+            self.surveygroup,
+            "euphorie.survey",
+            checkConstraints=False,
+            title=u"Survey"
+        )
         self.survey = self.surveygroup.survey
 
-        createContentInContainer(self.survey, "euphorie.risk",
-                checkConstraints=False, title=u"Risk")
+        createContentInContainer(
+            self.survey,
+            "euphorie.risk",
+            checkConstraints=False,
+            title=u"Risk"
+        )
         self.risk = self.survey['1']
         return self.survey
 
