@@ -1,46 +1,70 @@
-import sys
+# -*- coding: UTF-8 -*-
+"""
+Risk
+----
+
+An individual "question" about a risk that the user needs to answer.
+
+portal_type: euphorie.risk
+"""
+
+from .. import MessageFactory as _
+from .behaviour.richdescription import IRichDescription
+from .behaviour.uniqueid import get_next_id
+from .behaviour.uniqueid import INameFromUniqueId
+from .fti import check_fti_paste_allowed
+from .fti import ConditionalDexterityFTI
+from .fti import IConstructionFilter
+from .solution import ISolution
+from .utils import DragDropHelper
+from .utils import getTermTitleByValue
+from .utils import StripMarkup
 from Acquisition import aq_base
 from Acquisition import aq_chain
 from Acquisition import aq_inner
 from Acquisition import aq_parent
 from Acquisition.interfaces import IAcquirer
+from euphorie.content.utils import IToolTypesInfo
 from five import grok
-from zope.component import createObject
-from zope.component import getUtility
-from zope.interface import alsoProvides
-from zope.interface import noLongerProvides
-from zope.interface import implements
-from zope.interface import Interface
-from zope import schema
-from zope.schema.vocabulary import SimpleVocabulary
-from zope.schema.vocabulary import SimpleTerm
-from z3c.form.form import applyChanges
+from htmllaundry.z3cform import HtmlText
+from plone import api
+from plone.app.dexterity.behaviors.metadata import IBasic
 from plone.dexterity.interfaces import IDexterityFTI
 from plone.directives import dexterity
 from plone.directives import form
-from plone.app.dexterity.behaviors.metadata import IBasic
+from plone.indexer import indexer
+from plone.memoize.instance import memoize
 from plone.namedfile import field as filefield
 from plonetheme.nuplone.skin.interfaces import NuPloneSkin
 from plonetheme.nuplone.z3cform.directives import depends
 from plonetheme.nuplone.z3cform.form import FieldWidgetFactory
-from plone.indexer import indexer
-from htmllaundry.z3cform import HtmlText
-from .fti import ConditionalDexterityFTI
-from .fti import IConstructionFilter
-from .fti import check_fti_paste_allowed
-from .behaviour.richdescription import IRichDescription
-from .behaviour.uniqueid import INameFromUniqueId
-from .behaviour.uniqueid import get_next_id
-from .utils import getTermTitleByValue
-from .utils import StripMarkup
-from .solution import ISolution
-from .. import MessageFactory as _
+from z3c.appconfig.interfaces import IAppConfig
+from z3c.form.form import applyChanges
+from zope import schema
+from zope.component import createObject
+from zope.component import getUtility
+from zope.interface import alsoProvides
+from zope.interface import implements
+from zope.interface import Interface
+from zope.interface import noLongerProvides
+from zope.schema.vocabulary import SimpleTerm
+from zope.schema.vocabulary import SimpleVocabulary
+import sys
 
 grok.templatedir("templates")
 
 
 TextLines4Rows = FieldWidgetFactory(
-        "z3c.form.browser.textlines.TextLinesFieldWidget", rows=4)
+    "z3c.form.browser.textlines.TextLinesFieldWidget", rows=4)
+
+
+class TextLinesWithBreaks(schema.TextLine):
+
+    def constraint(self, value):
+        return True
+
+TextLines8Rows = FieldWidgetFactory(
+    "z3c.form.browser.textlines.TextLinesFieldWidget", rows=8)
 
 
 class IRisk(form.Schema, IRichDescription, IBasic):
@@ -48,18 +72,20 @@ class IRisk(form.Schema, IRichDescription, IBasic):
     """
 
     title = schema.TextLine(
-            title=_("label_statement", default=u"Statement"),
+            title=_("label_statement", default=u"Affirmative statement"),
             description=_("help_statement",
-                default=u"This is a short statement about a possible risk."),
+                default=u"This is a short affirmative statement about a "
+                    u"possible risk (e.g. The building is well maintained.)"),
             required=True)
+    form.widget(title="euphorie.content.risk.TextLines4Rows")
     form.order_before(title="*")
 
     problem_description = schema.TextLine(
             title=_("label_problem_description",
-                    default=u"Inversed statement"),
+                    default=u"Negative statement"),
             description=_("help_problem_description",
-                    default=u"This is the inverse of the statement: a "
-                            u"short description of current (bad) situation."),
+                    default=u"This is the inverse of the affirmative "
+                        u"statement (e.g. The building is not well maintained.)"),
             required=True)
     form.widget(problem_description="euphorie.content.risk.TextLines4Rows")
     form.order_after(problem_description="title")
@@ -67,12 +93,29 @@ class IRisk(form.Schema, IRichDescription, IBasic):
     description = HtmlText(
             title=_("label_description", default=u"Description"),
             description=_("help_risk_description",
-                default=u"Describe the risk. Include any relevant "
-                        u"information that may be helpful for users."),
+                default=u"Describe the risk. Include any relevant information "
+                    u"that may be helpful for the end-user."),
             required=True)
     form.widget(description="plone.app.z3cform.wysiwyg.WysiwygFieldWidget")
     form.order_after(description="problem_description")
 
+    existing_measures = TextLinesWithBreaks(
+        title=_(
+            "deprecated_label_existing_measures",
+            default=u"Measures that are already in place (Only shown here for "
+            u"reference! Use the “Add Measure” button on the Risk for adding "
+            u"measures that are shown to the user during Identification.)"),
+        description=_(
+            "help_existing_measures",
+            default=u"Use this field to define (common) measures that the "
+            u"user might have already implemented. "
+            u"Separate measures with a line break (Enter). The user will be "
+            u"able to deselect those measures that are not applicable to their"
+            u"situation."),
+        required=False)
+    form.widget(existing_measures="euphorie.content.risk.TextLines8Rows")
+    form.order_after(existing_measures="description")
+
     legal_reference = HtmlText(
             title=_("label_legal_reference",
                 default=u"Legal and policy references"),
@@ -95,14 +138,13 @@ class IRisk(form.Schema, IRichDescription, IBasic):
     type = schema.Choice(
             title=_("label_risk_type", default=u"Risk type"),
             description=_("help_risk_type",
-                default=u"'Risk' is related to the workplace. 'Policy' is "
-                        u"related to agreements, procedures and management "
-                        u"decisions. It can be answered from behind a desk "
-                        u"(no need to examine the workplace). 'Top 5' is one "
-                        "of the top five risks of the sector."),
+                default=u'"Priority risk" is one of the high risks in the '
+                    u'sector. "Risk" is related to the workplace or to the work '
+                    u'carried out. "Policy" refers to agreements, procedures, '
+                    u'and management decisions.'),
             vocabulary=SimpleVocabulary([
                             SimpleTerm(u"top5",
-                                title=_("risktype_top5", default=u"Top 5")),
+                                title=_("risktype_top5", default=u"Priority risk")),
                             SimpleTerm(u"risk",
                                 title=_("risktype_risk", default="Risk")),
                             SimpleTerm(u"policy",
@@ -111,6 +153,20 @@ class IRisk(form.Schema, IRichDescription, IBasic):
             default=u"risk",
             required=True)
 
+    depends("risk_always_present", "type", "==", "risk")
+    risk_always_present = schema.Bool(
+        title=_("label_risk_always_present", default=u"Risk is always present"),
+        description=_(
+            "description_risk_always_present",
+            default=u'If selected, the user will not be able to answer "Yes" or '
+            '"No", since the risk is considered to be always present. The '
+            'Evaluation and Action Plan will behave in the same way as for '
+            'regular risks.'
+        ),
+        required=False,
+        default=False,
+    )
+
     depends("evaluation_method", "type", "==", "risk")
     evaluation_method = schema.Choice(
             title=_("label_evaluation_method", default=u"Evaluation method"),
@@ -131,7 +187,7 @@ class IRisk(form.Schema, IRichDescription, IBasic):
     depends("fixed_priority", "type", "==", "risk")
     depends("fixed_priority", "evaluation_method", "==", "fixed")
     fixed_priority = schema.Choice(
-            title=_("label_fixed_priority", default=u"priority"),
+            title=_("report_timeline_priority", default=u"Priority"),
             vocabulary=SimpleVocabulary([
                 SimpleTerm("low", title=_("priority_low", default=u"Low")),
                 SimpleTerm("medium",
@@ -146,8 +202,8 @@ class IRisk(form.Schema, IRichDescription, IBasic):
     default_priority = schema.Choice(
             title=_("label_default_priority", default=u"Default priority"),
             description=_("help_default_priority",
-                default=u"You can help the user by selecting a default "
-                        u"priority. The user can still change the priority."),
+                default=u"You can help the end-user by selecting a default "
+                    u"priority. He/she can still change the priority."),
             vocabulary=SimpleVocabulary([
                 SimpleTerm("none",
                     title=_("no_default", default=u"No default")),
@@ -215,6 +271,65 @@ class IRisk(form.Schema, IRichDescription, IBasic):
             title=_("label_caption", default=u"Image caption"),
             required=False)
 
+    form.fieldset(
+        "additional_content",
+        label=_("header_additional_content", default=u"Additional content"),
+        description=_(
+            "intro_additional_content",
+            default=u"Attach any additional content you consider helpful "
+            "for the user"),
+        fields=[
+            "file1", "file1_caption", "file2", "file2_caption",
+            "file3", "file3_caption", "file4", "file4_caption"])
+
+    file1 = filefield.NamedBlobFile(
+        title=_("label_file", default=u"Content file"),
+        description=_(
+            "help_content_upload",
+            default=u"Upload a file that contains additional information, "
+            u"like a PDF, Word document or spreadsheet. Optionally provide "
+            u"a descriptive caption for your file."),
+        required=False)
+    file1_caption = schema.TextLine(
+        title=_("label_file_caption", default=u"Content caption"),
+        required=False)
+
+    file2 = filefield.NamedBlobFile(
+        title=_("label_file", default=u"Content file"),
+        description=_(
+            "help_content_upload",
+            default=u"Upload a file that contains additional information, "
+            u"like a PDF, Word document or spreadsheet. Optionally provide "
+            u"a descriptive caption for your file."),
+        required=False)
+    file2_caption = schema.TextLine(
+        title=_("label_file_caption", default=u"Content caption"),
+        required=False)
+
+    file3 = filefield.NamedBlobFile(
+        title=_("label_file", default=u"Content file"),
+        description=_(
+            "help_content_upload",
+            default=u"Upload a file that contains additional information, "
+            u"like a PDF, Word document or spreadsheet. Optionally provide "
+            u"a descriptive caption for your file."),
+        required=False)
+    file3_caption = schema.TextLine(
+        title=_("label_file_caption", default=u"Content caption"),
+        required=False)
+
+    file4 = filefield.NamedBlobFile(
+        title=_("label_file", default=u"Content file"),
+        description=_(
+            "help_content_upload",
+            default=u"Upload a file that contains additional information, "
+            u"like a PDF, Word document or spreadsheet. Optionally provide "
+            u"a descriptive caption for your file."),
+        required=False)
+    file4_caption = schema.TextLine(
+        title=_("label_file_caption", default=u"Content caption"),
+        required=False)
+
 
 class IFrenchEvaluation(form.Schema):
     depends("default_severity", "type", "==", "risk")
@@ -335,7 +450,7 @@ class IKinneyRisk(IRisk, IKinneyEvaluation):
                 default=u"You can specify how the risks priority is "
                         u"evaluated. For more details see the online "
                         u"manual."),
-            fields=["type", "evaluation_method",
+            fields=["type", "risk_always_present", "evaluation_method",
                     "fixed_priority",
                     "default_priority",
                     "default_probability", "default_frequency",
@@ -349,7 +464,7 @@ class IFrenchRisk(IRisk, IFrenchEvaluation):
                 default=u"You can specify how the risks priority is "
                         u"evaluated. For more details see the online "
                         u"manual."),
-            fields=["type", "evaluation_method",
+            fields=["type", "risk_always_present", "evaluation_method",
                     "fixed_priority",
                     "default_priority",
                     "default_severity", "default_frequency"])
@@ -373,6 +488,14 @@ class Risk(dexterity.Container):
     caption3 = None
     image4 = None
     caption4 = None
+    file1 = None
+    file1_caption = None
+    file2 = None
+    file2_caption = None
+    file3 = None
+    file3_caption = None
+    file4 = None
+    file4_caption = None
 
     def _get_id(self, orig_id):
         """Pick an id for pasted content."""
@@ -396,12 +519,43 @@ class Risk(dexterity.Container):
 
     @property
     def fixed_priority(self):
-        return self.default_priority
+        priority = self.default_priority
+        # 'none' is acceptable for default_priority, but not for fixed_priority,
+        # so in that case default it to 'low'.
+        if priority == 'none':
+            return 'low'
+        return priority
 
     @fixed_priority.setter
     def fixed_priority(self, value):
         self.default_priority = value
 
+    @property
+    @memoize
+    def _solutions(self):
+        solutions = []
+        for item in self.objectValues():
+            if ISolution.providedBy(item):
+                solutions.append(item)
+        return solutions
+
+    def get_pre_defined_measures(self, request=None):
+        """ Iterate over the Solution items on this risk.
+        """
+        measures = []
+        webhelpers = api.content.get_view("webhelpers", self, request)
+        for item in self._solutions:
+            description = item.description and item.description.strip() or ""
+            prevention_plan = (
+                item.prevention_plan and item.prevention_plan.strip() or "")
+            measure = description
+            if webhelpers.country in ("it", ):
+                if prevention_plan:
+                    measure = u"%s: %s" % (measure, prevention_plan)
+            measures.append(measure)
+
+        return measures
+
 
 def EnsureInterface(risk):
     """Make sure a risk has the correct interface set for, matching the
@@ -423,10 +577,6 @@ def evaluation_algorithm(context):
     """
     from euphorie.content.surveygroup import ISurveyGroup  # XXX Circular
     for parent in aq_chain(aq_inner(context)):
-        if IFrenchEvaluation.providedBy(parent):
-            return u"french"
-        elif IKinneyEvaluation.providedBy(parent):
-            return u"kinney"
         if ISurveyGroup.providedBy(parent):
             return parent.evaluation_algorithm
     return u"kinney"
@@ -440,7 +590,7 @@ def SearchableTextIndexer(obj):
                      StripMarkup(obj.legal_reference)])
 
 
-class View(grok.View):
+class View(grok.View, DragDropHelper):
     grok.context(IRisk)
     grok.require("zope2.View")
     grok.layer(NuPloneSkin)
@@ -490,12 +640,14 @@ class Add(dexterity.AddForm):
     default_fieldset_label = None
 
     def __init__(self, context, request):
+        from euphorie.content.survey import get_tool_type
         dexterity.AddForm.__init__(self, context, request)
         self.evaluation_algorithm = evaluation_algorithm(context)
         self.order = ['header_identification',
                  'header_evaluation',
                  'header_main_image',
-                 'header_secondary_images']
+                 'header_secondary_images',
+                 'header_additional_content']
 
     @property
     def schema(self):
@@ -511,6 +663,7 @@ class Add(dexterity.AddForm):
     def updateWidgets(self):
         super(Add, self).updateWidgets()
         self.widgets["title"].addClass("span-7")
+        self.widgets["existing_measures"].mode = "hidden"
 
     def create(self, data):
         # This is mostly a direct copy of
@@ -535,20 +688,25 @@ class Edit(form.SchemaEditForm):
     grok.require("cmf.ModifyPortalContent")
     grok.layer(NuPloneSkin)
     grok.name("edit")
-    grok.template("risk_edit")
 
     default_fieldset_label = None
 
     def __init__(self, context, request):
+        from euphorie.content.survey import get_tool_type
         self.order = ['header_identification',
                       'header_evaluation',
                       'header_main_image',
-                      'header_secondary_images']
+                      'header_secondary_images',
+                      'header_additional_content']
         self.evaluation_algorithm = context.evaluation_algorithm()
         if self.evaluation_algorithm == u"french":
             self.schema = IFrenchRisk
         else:
             self.schema = IKinneyRisk
+        appconfig = getUtility(IAppConfig)
+        settings = appconfig.get('euphorie')
+        self.use_existing_measures = settings.get('use_existing_measures', False)
+        self.tool_type = get_tool_type(context)
         form.SchemaEditForm.__init__(self, context, request)
 
     def updateFields(self):
@@ -558,6 +716,20 @@ class Edit(form.SchemaEditForm):
     def updateWidgets(self):
         super(Edit, self).updateWidgets()
         self.widgets["title"].addClass("span-7")
+        tt = getUtility(IToolTypesInfo)
+        if not (
+            self.use_existing_measures and
+            self.tool_type in tt.types_existing_measures
+        ):
+            self.widgets["existing_measures"].mode = "hidden"
+        else:
+            self.widgets["existing_measures"].mode = "display"
+
+    def extractData(self, setErrors=True):
+        data = super(Edit, self).extractData(setErrors)
+        if data[0]['evaluation_method'] == 'fixed':
+            del data[0]['default_priority']
+        return data
 
 
 class ConstructionFilter(grok.MultiAdapter):
@@ -590,3 +762,7 @@ class ConstructionFilter(grok.MultiAdapter):
 
     def allowed(self):
         return self.checkForModules()
+
+
+def handle_risk_pasted(risk, event):
+    EnsureInterface(risk)
