@@ -12,39 +12,41 @@ framework.
 .. _membrane: http://pypi.python.org/pypi/Products.membrane
 """
 
-import datetime
-import logging
-import zExceptions
+from .. import MessageFactory as _
 from Acquisition import aq_base
 from Acquisition import aq_chain
 from Acquisition import aq_inner
-from zope.interface import implements
-from zope import schema
-from five import grok
-from zope.component import getUtility
-from z3c.appconfig.interfaces import IAppConfig
-from plone.directives import dexterity
-from plone.directives import form
-from plone.app.dexterity.behaviors.metadata import IBasic
-from plone.namedfile import field as filefield
-from plone.indexer import indexer
-from plone.uuid.interfaces import IAttributeUUID
-from Products.CMFCore.utils import getToolByName
-from Products.CMFEditions.Permissions import AccessPreviousVersions
-from Products.statusmessages.interfaces import IStatusMessage
 from borg.localrole.interfaces import ILocalRoleProvider
-from .. import MessageFactory as _
-from euphorie.content import colour
 from euphorie.content.behaviour.dirtytree import isDirty
 from euphorie.content.survey import ISurvey
 from euphorie.content.surveygroup import ISurveyGroup
 from euphorie.content.user import IUser
 from euphorie.content.user import UserProvider
+from five import grok
+from plone import api
+from plone.app.dexterity.behaviors.metadata import IBasic
 from plone.app.layout.navigation.interfaces import INavigationRoot
+from plone.directives import dexterity
+from plone.directives import form
+from plone.indexer import indexer
+from plone.namedfile import field as filefield
+from plone.uuid.interfaces import IAttributeUUID
+from plonetheme.nuplone.skin import actions
 from plonetheme.nuplone.skin.interfaces import NuPloneSkin
 from plonetheme.nuplone.utils import checkPermission
-from plonetheme.nuplone.skin import actions
 from plonetheme.nuplone.utils import getPortal
+from Products.CMFCore.utils import getToolByName
+from Products.CMFEditions.Permissions import AccessPreviousVersions
+from Products.statusmessages.interfaces import IStatusMessage
+from z3c.appconfig.interfaces import IAppConfig
+from zope import schema
+from zope.component import getUtility
+from zope.interface import implements
+
+import datetime
+import logging
+import zExceptions
+
 
 log = logging.getLogger(__name__)
 grok.templatedir("templates")
@@ -78,18 +80,10 @@ class ISector(form.Schema, IUser, IBasic):
             title=_("label_logo", default=u"Logo"),
             description=_("help_image_upload",
                 default=u"Upload an image. Make sure your image is of format "
-                        u"png, jpg or gif and does not contain any special  "
+                        u"png, jpg or gif and does not contain any special "
                         u"characters."),
             required=False)
 
-    main_colour = colour.Colour(
-            title=_("label_main_colour", default=u"Main colour"),
-            required=False)
-
-    support_colour = colour.Colour(
-            title=_("label_support_colour", default=u"Support colour"),
-            required=False)
-
 
 class Sector(dexterity.Container):
     """A sector of industry.
@@ -97,13 +91,14 @@ class Sector(dexterity.Container):
     A sector also acts as a user account in the system, using the membrane
     framework.
     """
+    portal_type = "euphorie.clientsector"
     implements(ISector, INavigationRoot, IAttributeUUID)
 
     locked = False
 
     def _canCopy(self, op=0):
         """Tell Zope2 that this object can not be copied."""
-        return False
+        return op
 
 
 @indexer(ISector)
@@ -179,10 +174,12 @@ def getSurveys(context):
     allow_history = checkPermission(context, AccessPreviousVersions)
 
     def morph(group, survey):
+        published = survey.id == group.published
         info = {'id': survey.id,
                 'title': survey.title,
                 'url': survey.absolute_url(),
-                'published': survey.id == group.published,
+                'published': published,
+                'publication_date': published and survey.published or None,
                 'current': aq_base(survey) is current_version,
                 'modified': isDirty(survey),
                 'versions': []}
@@ -228,6 +225,10 @@ class View(grok.View):
         self.add_survey_url = "%s/++add++euphorie.surveygroup" % \
                 aq_inner(self.context).absolute_url()
         self.surveys = getSurveys(self.context)
+        permission = "Euphorie: Add new RIE Content"
+        user = api.user.get_current()
+        self.can_add = api.user.has_permission(
+            permission, user=user, obj=self.context)
         super(View, self).update()
 
 
@@ -260,7 +261,7 @@ class Delete(actions.Delete):
             flash(
                 _("message_not_delete_published_sector",
                 default=u"You can not delete a sector that contains published "
-                        u"surveys."), "error")
+                        u"OiRA Tools."), "error")
             self.request.response.redirect(context.absolute_url())
             return False
         return True
@@ -275,7 +276,7 @@ class ColourPreview(grok.View):
 
     def default_title(self):
         from .. import MessageFactory as _
-        return _("title_tool", default=u"OiRA")
+        return _('title_tool', default=u'OiRA - Online interactive Risk Assessment')
 
 
 class Settings(form.SchemaEditForm):
@@ -287,14 +288,7 @@ class Settings(form.SchemaEditForm):
 
     schema = ISector
     default_fieldset_label = None
-
-    def update(self):
-        super(Settings, self).update()
-        config = getUtility(IAppConfig).get("euphorie", {})
-        self.main_colour = config.get("main_colour", '#031c48')
-        self.support_colour = config.get("support_colour", '#e69d17')
-        self.main_bg_colour = config.get("main_bg_colour", '#031c48')
-        self.support_bg_colour = config.get("support_bg_colour", '#e69d17')
+    formErrorsMessage = u"Please correct the indicated errors."
 
     def extractData(self):
         self.fields = self.fields.omit("title", "login")
