@@ -1,38 +1,53 @@
+# coding=utf-8
+from Acquisition import aq_parent
+from euphorie.content import upload
+from euphorie.content.module import Module
+from euphorie.content.profilequestion import ProfileQuestion
+from euphorie.content.risk import IFrenchEvaluation
+from euphorie.content.risk import IKinneyEvaluation
+from euphorie.content.risk import Risk
+from euphorie.content.solution import Solution
+from euphorie.testing import EuphorieFunctionalTestCase
+from euphorie.testing import EuphorieIntegrationTestCase
 from lxml import objectify
 from plone.dexterity.utils import createContentInContainer
-from euphorie.deployment.tests.functional import EuphorieTestCase
-from euphorie.content import upload
+from plone.namedfile.file import NamedBlobImage
+from plone.uuid.interfaces import IUUID
 
 
-class SurveyImporterTests(EuphorieTestCase):
+class SurveyImporterTests(EuphorieIntegrationTestCase):
+
     def createSurveyGroup(self):
         country = self.portal.sectors.nl
-        sector = createContentInContainer(country,
-                "euphorie.sector", title="sector")
-        return createContentInContainer(sector,
-                "euphorie.surveygroup", title="group")
+        sector = createContentInContainer(
+            country, "euphorie.sector", title="sector"
+        )
+        return createContentInContainer(
+            sector, "euphorie.surveygroup", title="group"
+        )
 
     def createSurvey(self):
         surveygroup = self.createSurveyGroup()
-        return createContentInContainer(surveygroup,
-                "euphorie.survey", title="survey")
+        return createContentInContainer(
+            surveygroup, "euphorie.survey", title="survey"
+        )
 
     def createModule(self):
         survey = self.createSurvey()
-        return createContentInContainer(survey,
-                "euphorie.module", title="module")
+        return createContentInContainer(
+            survey, "euphorie.module", title="module"
+        )
 
     def createRisk(self):
         module = self.createModule()
-        return createContentInContainer(module,
-                "euphorie.risk", title="risk")
+        return createContentInContainer(module, "euphorie.risk", title="risk")
 
     def testImportImage(self):
-        from plone.namedfile.file import NamedBlobImage
         snippet = objectify.fromstring(
-                '<image caption="Key image" filename="myfile.gif" '
-                'content-type="image/gif">R0lGODlhAQABAIAAAAAAAP//'
-                '/yH5BAEAAAEALAAAAAABAAEAAAIBTAA7</image>')
+            '<image caption="Key image" filename="myfile.gif" '
+            'content-type="image/gif">R0lGODlhAQABAIAAAAAAAP//'
+            '/yH5BAEAAAEALAAAAAABAAEAAAIBTAA7</image>'
+        )
         importer = upload.SurveyImporter(None)
         (image, caption) = importer.ImportImage(snippet)
         self.assertEqual(caption, u"Key image")
@@ -43,17 +58,19 @@ class SurveyImporterTests(EuphorieTestCase):
 
     def testImportImage_filename_from_mimetype(self):
         snippet = objectify.fromstring(
-                '<image caption="Key image" content-type="image/bmp">'
-                'R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAEALAAAAAABAAEAAAIB'
-                'TAA7</image>')
+            '<image caption="Key image" content-type="image/bmp">'
+            'R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAEALAAAAAABAAEAAAIB'
+            'TAA7</image>'
+        )
         importer = upload.SurveyImporter(None)
         (image, caption) = importer.ImportImage(snippet)
         self.assertTrue(image.filename.endswith('.bmp'))
 
     def testImportImage_MimeFromFilename(self):
         snippet = objectify.fromstring(
-                '<image filename="tiny.gif">R0lGODlhAQABAIAAAAAAAP///yH5BAEAAA'
-                'EALAAAAAABAAEAAAIBTAA7</image>')
+            '<image filename="tiny.gif">R0lGODlhAQABAIAAAAAAAP///yH5BAEAAA'
+            'EALAAAAAABAAEAAAIBTAA7</image>'
+        )
         importer = upload.SurveyImporter(None)
         (image, caption) = importer.ImportImage(snippet)
         self.assertEqual(caption, None)
@@ -64,42 +81,41 @@ class SurveyImporterTests(EuphorieTestCase):
 
     def testImportSolution(self):
         snippet = objectify.fromstring(
-        """<solution xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<solution xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <description>Add more abstraction layers</description>
              <action-plan>Add another level</action-plan>
              <prevention-plan>Ask a code reviewer to verify the design</prevention-plan>
              <requirements>A good understanding of architecture</requirements>
-           </solution>""")
-        self.loginAsPortalOwner()
+           </solution>"""  # noqa
+        )
         risk = self.createRisk()
         importer = upload.SurveyImporter(None)
-        importer.ImportSolution(snippet, risk)
+        solution = importer.ImportSolution(snippet, risk)
         self.assertEqual(risk.keys(), ["3"])
-        solution = risk["3"]
         self.assertEqual(solution.description, u"Add more abstraction layers")
         self.failUnless(isinstance(solution.description, unicode))
         self.assertEqual(solution.action_plan, u"Add another level")
         self.failUnless(isinstance(solution.action_plan, unicode))
         self.assertEqual(
-                solution.prevention_plan,
-                u"Ask a code reviewer to verify the design")
+            solution.prevention_plan,
+            u"Ask a code reviewer to verify the design"
+        )
         self.failUnless(isinstance(solution.prevention_plan, unicode))
         self.assertEqual(
-                solution.requirements,
-                u"A good understanding of architecture")
+            solution.requirements, u"A good understanding of architecture"
+        )
         self.failUnless(isinstance(solution.requirements, unicode))
 
     def testImportSolution_MissingFields(self):
         snippet = objectify.fromstring(
-        """<solution xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<solution xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <description>Add more abstraction layers</description>
              <action-plan>Add another level</action-plan>
-           </solution>""")
-        self.loginAsPortalOwner()
+           </solution>"""
+        )
         risk = self.createRisk()
         importer = upload.SurveyImporter(None)
-        importer.ImportSolution(snippet, risk)
-        solution = risk["3"]
+        solution = importer.ImportSolution(snippet, risk)
         self.assertEqual(solution.description, u"Add more abstraction layers")
         self.assertEqual(solution.action_plan, u"Add another level")
         self.assertEqual(solution.prevention_plan, None)
@@ -107,28 +123,29 @@ class SurveyImporterTests(EuphorieTestCase):
 
     def testImportRisk(self):
         snippet = objectify.fromstring(
-        """<risk type="policy" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<risk type="policy" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Are your desks at the right height?</title>
              <problem-description>Not all desks are set to the right height.</problem-description>
              <description>&lt;p&gt;The right height is important to prevent back problems.&lt;/p&gt;</description>
              <legal-reference>&lt;p&gt;See ARBO policies.&lt;/p&gt;</legal-reference>
              <show-not-applicable>true</show-not-applicable>
              <evaluation-method>direct</evaluation-method>
-           </risk>""")
-        self.loginAsPortalOwner()
+           </risk>"""  # noqa
+        )
         module = self.createModule()
         importer = upload.SurveyImporter(None)
-        importer.ImportRisk(snippet, module)
-        risk = module["2"]
+        risk = importer.ImportRisk(snippet, module)
         self.assertEqual(risk.title, u"Are your desks at the right height?")
         self.failUnless(isinstance(risk.title, unicode))
         self.assertEqual(
-                risk.problem_description,
-                u"Not all desks are set to the right height.")
+            risk.problem_description,
+            u"Not all desks are set to the right height."
+        )
         self.failUnless(isinstance(risk.problem_description, unicode))
         self.assertEqual(
-                risk.description,
-                u"<p>The right height is important to prevent back problems.</p>")
+            risk.description,
+            u"<p>The right height is important to prevent back problems.</p>"
+        )
         self.failUnless(isinstance(risk.description, unicode))
         self.assertEqual(risk.legal_reference, u"<p>See ARBO policies.</p>")
         self.failUnless(isinstance(risk.legal_reference, unicode))
@@ -139,7 +156,7 @@ class SurveyImporterTests(EuphorieTestCase):
 
     def testImportRisk_Images(self):
         snippet = objectify.fromstring(
-        """<risk type="policy" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<risk type="policy" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Are your desks at the right height?</title>
              <problem-description>Not all desks are set to the right height.</problem-description>
              <description>&lt;p&gt;The right height is important to prevent back problems.&lt;/p&gt;</description>
@@ -151,12 +168,11 @@ class SurveyImporterTests(EuphorieTestCase):
              <image caption="Image 3" filename="tiny.gif">R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAEALAAAAAABAAEAAAIBTAA7</image>
              <image caption="Image 4" filename="tiny.gif">R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAEALAAAAAABAAEAAAIBTAA7</image>
              <image caption="Image 5" filename="tiny.gif">R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAEALAAAAAABAAEAAAIBTAA7</image>
-           </risk>""")
-        self.loginAsPortalOwner()
+           </risk>"""  # noqa
+        )
         module = self.createModule()
         importer = upload.SurveyImporter(None)
-        importer.ImportRisk(snippet, module)
-        risk = module["2"]
+        risk = importer.ImportRisk(snippet, module)
         self.assertEqual(risk.image.filename, "tiny.gif")
         self.assertEqual(risk.caption, u"Key image")
         self.assertEqual(risk.image2.filename, "tiny.gif")
@@ -168,28 +184,27 @@ class SurveyImporterTests(EuphorieTestCase):
 
     def testImportRisk_DirectEvaluation(self):
         snippet = objectify.fromstring(
-        """<risk type="risk" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<risk type="risk" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Are your desks at the right height?</title>
              <description>&lt;p&gt;The right height is important to prevent back problems.&lt;/p&gt;</description>
              <evaluation-method default-priority="high">direct</evaluation-method>
-           </risk>""")
-        self.loginAsPortalOwner()
+           </risk>"""  # noqa
+        )
         module = self.createModule()
         importer = upload.SurveyImporter(None)
-        importer.ImportRisk(snippet, module)
-        risk = module["2"]
+        risk = importer.ImportRisk(snippet, module)
         self.assertEqual(risk.show_notapplicable, False)
         self.assertEqual(risk.evaluation_method, "direct")
         self.assertEqual(risk.default_priority, "high")
 
     def testImportRisk_CalculatedEvaluation_Kinney(self):
-        from euphorie.content.risk import IKinneyEvaluation
         snippet = objectify.fromstring(
-        """<risk type="risk" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<risk type="risk" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Are your desks at the right height?</title>
              <description>&lt;p&gt;The right height is important to prevent back problems.&lt;/p&gt;</description>
              <evaluation-method default-probability="small" default-frequency="regular" default-effect="high">calculated</evaluation-method>
-           </risk>""")
+           </risk>"""  # noqa
+        )
         self.loginAsPortalOwner()
         module = self.createModule()
         importer = upload.SurveyImporter(None)
@@ -203,21 +218,19 @@ class SurveyImporterTests(EuphorieTestCase):
         self.assertEqual(risk.default_effect, 10)
 
     def testImportRisk_CalculatedEvaluation_French(self):
-        from Acquisition import aq_parent
-        from euphorie.content.risk import IFrenchEvaluation
         snippet = objectify.fromstring(
-        """<risk type="risk" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<risk type="risk" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Are your desks at the right height?</title>
              <description>&lt;p&gt;The right height is important to prevent back problems.&lt;/p&gt;</description>
              <evaluation-method default-severity="very-severe" default-frequency="often">calculated</evaluation-method>
-           </risk>""")
+           </risk>"""  # noqa
+        )
         self.loginAsPortalOwner()
         module = self.createModule()
         group = aq_parent(aq_parent(module))
         group.evaluation_algorithm = u"french"
         importer = upload.SurveyImporter(None)
-        importer.ImportRisk(snippet, module)
-        risk = module["2"]
+        risk = importer.ImportRisk(snippet, module)
         self.assertTrue(IFrenchEvaluation.providedBy(risk))
         self.assertEqual(risk.show_notapplicable, False)
         self.assertEqual(risk.evaluation_method, "calculated")
@@ -226,7 +239,7 @@ class SurveyImporterTests(EuphorieTestCase):
 
     def testImportRisk_WithSolution(self):
         snippet = objectify.fromstring(
-        """<risk type="policy" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<risk type="policy" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Are your desks at the right height?</title>
              <description>&lt;p&gt;The right height is important to prevent back problems.&lt;/p&gt;</description>
              <evaluation-method>direct</evaluation-method>
@@ -236,101 +249,101 @@ class SurveyImporterTests(EuphorieTestCase):
                  <action-plan>Order height-adjustable desks for desk workers.</action-plan>
                </solution>
              </solutions>
-           </risk>""")
+           </risk>"""  # noqa
+        )
         self.loginAsPortalOwner()
         module = self.createModule()
         importer = upload.SurveyImporter(None)
-        importer.ImportRisk(snippet, module)
-        risk = module["2"]
+        risk = importer.ImportRisk(snippet, module)
         self.assertEqual(risk.keys(), ["3"])
         solution = risk["3"]
-        from euphorie.content.solution import Solution
         self.failUnless(isinstance(solution, Solution))
         self.assertEqual(solution.description, u"Use height-adjustable desks")
 
     def testImportModule(self):
         snippet = objectify.fromstring(
-        """<module optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<module optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Design patterns</title>
              <description>&lt;p&gt;Software design patterns are critical.&lt;/p&gt;</description>
              <solution-direction>&lt;p&gt;Buy the book from the gang of four.&lt;/p&gt;</solution-direction>
-           </module>""")
+           </module>"""  # noqa
+        )
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         importer = upload.SurveyImporter(None)
-        importer.ImportModule(snippet, survey)
-        module = survey["1"]
+        module = importer.ImportModule(snippet, survey)
         self.assertEqual(module.title, u"Design patterns")
         self.failUnless(isinstance(module.title, unicode))
         self.assertEqual(module.optional, False)
         self.assertEqual(module.question, None)
         self.assertEqual(
-                module.description,
-                u"<p>Software design patterns are critical.</p>")
+            module.description,
+            u"<p>Software design patterns are critical.</p>"
+        )
         self.failUnless(isinstance(module.description, unicode))
         self.assertEqual(
-                module.solution_direction,
-                u"<p>Buy the book from the gang of four.</p>")
+            module.solution_direction,
+            u"<p>Buy the book from the gang of four.</p>"
+        )
         self.failUnless(isinstance(module.solution_direction, unicode))
         self.assertEqual(module.keys(), [])
         self.assertEqual(module.image, None)
 
     def testImportModule_Image(self):
         snippet = objectify.fromstring(
-        """<module optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<module optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Design patterns</title>
              <description>&lt;p&gt;Software design patterns are critical.&lt;/p&gt;</description>
              <solution-direction>&lt;p&gt;Buy the book from the gang of four.&lt;/p&gt;</solution-direction>
              <image caption="My caption" content-type="image/gif">R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAEALAAAAAABAAEAAAIBTAA7</image>
-           </module>""")
+           </module>"""  # noqa
+        )
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         importer = upload.SurveyImporter(None)
-        importer.ImportModule(snippet, survey)
-        module = survey["1"]
+        module = importer.ImportModule(snippet, survey)
         self.assertNotEqual(module.image, None)
         self.assertEqual(module.image.contentType, "image/gif")
         self.assertEqual(module.caption, u'My caption')
 
     def testImportModule_Optional(self):
         snippet = objectify.fromstring(
-        """<module optional="true" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<module optional="true" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Design patterns</title>
              <description>&lt;p&gt;Software design patterns are critical.&lt;/p&gt;</description>
              <question>Have you used design patterns?</question>
-           </module>""")
+           </module>"""  # noqa
+        )
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         importer = upload.SurveyImporter(None)
-        importer.ImportModule(snippet, survey)
-        module = survey["1"]
+        module = importer.ImportModule(snippet, survey)
         self.assertEqual(module.optional, True)
         self.assertEqual(module.question, u"Have you used design patterns?")
 
     def testImportModule_WithSubModule(self):
         snippet = objectify.fromstring(
-        """<module optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<module optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Design patterns</title>
              <description>&lt;p&gt;Software design patterns are critical.&lt;/p&gt;</description>
              <module optional="no">
                <title>Iterators</title>
                <description>&lt;p&gt;Iterators help optimise list handling.&lt;/p&gt;</description>
              </module>
-           </module>""")
+           </module>"""  # noqa
+        )
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         importer = upload.SurveyImporter(None)
-        importer.ImportModule(snippet, survey)
-        module = survey["1"]
+        module = importer.ImportModule(snippet, survey)
         self.assertEqual(module.keys(), ["2"])
         module = module["2"]
-        from euphorie.content.module import Module
         self.failUnless(isinstance(module, Module))
         self.assertEqual(module.title, u"Iterators")
 
     def testImportModule_WithRisk(self):
         snippet = objectify.fromstring(
-        """<module optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<module optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Design patterns</title>
              <description>&lt;p&gt;Software design patterns are critical.&lt;/p&gt;</description>
              <risk type="policy">
@@ -338,44 +351,60 @@ class SurveyImporterTests(EuphorieTestCase):
                <description>&lt;p&gt;Every developer should know about them..&lt;/p&gt;</description>
                <evaluation-method>direct</evaluation-method>
              </risk>
-           </module>""")
+           </module>"""  # noqa
+        )
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         importer = upload.SurveyImporter(None)
-        importer.ImportModule(snippet, survey)
-        module = survey["1"]
+        module = importer.ImportModule(snippet, survey)
         self.assertEqual(module.keys(), ["2"])
         risk = module["2"]
-        from euphorie.content.risk import Risk
         self.failUnless(isinstance(risk, Risk))
         self.assertEqual(
-                risk.title,
-                u"New hires are not aware of design patterns.")
+            risk.title, u"New hires are not aware of design patterns."
+        )
 
     def testImportProfileQuestion(self):
         snippet = objectify.fromstring(
-        """<profile-question type="optional" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<profile-question xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Laptop usage</title>
              <question>Do your employees use laptops?</question>
              <description>&lt;p&gt;Laptops are very common in the modern workplace.&lt;/p&gt;</description>
-           </profile-question>""")
+           </profile-question>"""  # noqa
+        )
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         importer = upload.SurveyImporter(None)
-        importer.ImportProfileQuestion(snippet, survey)
-        profile = survey["1"]
+        profile = importer.ImportProfileQuestion(snippet, survey)
         self.assertEqual(profile.title, u"Laptop usage")
         self.failUnless(isinstance(profile.title, unicode))
-        self.assertEqual(profile.type, "optional")
         self.assertEqual(profile.question, u"Do your employees use laptops?")
         self.failUnless(isinstance(profile.question, unicode))
-        self.assertEqual(profile.description, u"<p>Laptops are very common in the modern workplace.</p>")
+        self.assertEqual(
+            profile.description,
+            u"<p>Laptops are very common in the modern workplace.</p>"
+        )
         self.failUnless(isinstance(profile.description, unicode))
         self.assertEqual(profile.keys(), [])
 
+    def testImportProfileQuestion_optional_type(self):
+        snippet = objectify.fromstring(
+            """<profile-question type="optional"
+                xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+             <title>Laptop usage</title>
+             <question>Do your employees use laptops?</question>
+           </profile-question>"""
+        )
+        self.loginAsPortalOwner()
+        survey = self.createSurvey()
+        importer = upload.SurveyImporter(None)
+        profile = importer.ImportProfileQuestion(snippet, survey)
+        self.assertTrue(isinstance(profile, Module))
+        self.assertEqual(profile.optional, True)
+
     def testImportProfileQuestion_WithModule(self):
         snippet = objectify.fromstring(
-        """<profile-question type="optional" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<profile-question xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Laptop usage</title>
              <question>Do your employees use laptops?</question>
              <description>&lt;p&gt;Laptops are very common in the modern workplace.&lt;/p&gt;</description>
@@ -383,21 +412,20 @@ class SurveyImporterTests(EuphorieTestCase):
                <title>Design patterns</title>
                <description>&lt;p&gt;Software design patterns are critical.&lt;/p&gt;</description>
              </module>
-           </profile-question>""")
+           </profile-question>"""  # noqa
+        )
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         importer = upload.SurveyImporter(None)
-        importer.ImportProfileQuestion(snippet, survey)
-        profile = survey["1"]
+        profile = importer.ImportProfileQuestion(snippet, survey)
         self.assertEqual(profile.keys(), ["2"])
         module = profile["2"]
-        from euphorie.content.module import Module
         self.failUnless(isinstance(module, Module))
         self.assertEqual(module.title, u"Design patterns")
 
     def testImportProfileQuestion_WithRisk(self):
         snippet = objectify.fromstring(
-        """<profile-question type="optional" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<profile-question xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Laptop usage</title>
              <question>Do your employees use laptops?</question>
              <description>&lt;p&gt;Laptops are very common in the modern workplace.&lt;/p&gt;</description>
@@ -406,95 +434,92 @@ class SurveyImporterTests(EuphorieTestCase):
                <description>&lt;p&gt;Every developer should know about them..&lt;/p&gt;</description>
                <evaluation-method>direct</evaluation-method>
              </risk>
-           </profile-question>""")
+           </profile-question>"""  # noqa
+        )
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         importer = upload.SurveyImporter(None)
-        importer.ImportProfileQuestion(snippet, survey)
-        profile = survey["1"]
+        profile = importer.ImportProfileQuestion(snippet, survey)
         self.assertEqual(profile.keys(), ["2"])
         risk = profile["2"]
-        from euphorie.content.risk import Risk
         self.failUnless(isinstance(risk, Risk))
         self.assertEqual(
-                risk.title,
-                u"New hires are not aware of design patterns.")
+            risk.title, u"New hires are not aware of design patterns."
+        )
 
     def testImportSurvey(self):
         snippet = objectify.fromstring(
-        """<survey xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<survey xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Software development</title>
              <classification-code>A.1.2.3</classification-code>
              <language>nl</language>
              <evaluation-optional>true</evaluation-optional>
-           </survey>""")
+           </survey>"""
+        )
         self.loginAsPortalOwner()
         surveygroup = self.createSurveyGroup()
         importer = upload.SurveyImporter(None)
-        importer.ImportSurvey(snippet, surveygroup, u"Fresh import")
+        survey = importer.ImportSurvey(snippet, surveygroup, u"Fresh import")
         self.assertEqual(surveygroup.keys(), ["fresh-import"])
-        survey = surveygroup["fresh-import"]
         self.assertEqual(survey.keys(), [])
         self.assertEqual(survey.title, u"Fresh import")
         self.failUnless(isinstance(survey.title, unicode))
         self.assertEqual(survey.classification_code, u"A.1.2.3")
         self.failUnless(isinstance(survey.language, str))
         self.assertEqual(survey.language, "nl")
-        self.failUnless(isinstance(survey.classification_code, str))
+        self.failUnless(isinstance(survey.classification_code, unicode))
         self.assertEqual(survey.evaluation_optional, True)
 
     def testImportSurvey_WithModule(self):
         snippet = objectify.fromstring(
-        """<survey optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<survey optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Software development</title>
              <module optional="no">
                <title>Design patterns</title>
                <description>&lt;p&gt;Software design patterns are critical.&lt;/p&gt;</description>
              </module>
-           </survey>""")
+           </survey>"""  # noqa
+        )
         self.loginAsPortalOwner()
         surveygroup = self.createSurveyGroup()
         importer = upload.SurveyImporter(None)
-        importer.ImportSurvey(snippet, surveygroup, u"Fresh import")
+        survey = importer.ImportSurvey(snippet, surveygroup, u"Fresh import")
         self.assertEqual(surveygroup.keys(), ["fresh-import"])
-        survey = surveygroup["fresh-import"]
         self.assertEqual(survey.keys(), ["1"])
         module = survey["1"]
-        from euphorie.content.module import Module
         self.failUnless(isinstance(module, Module))
         self.assertEqual(module.title, u"Design patterns")
 
     def testImportSurvey_WithProfileQuestion(self):
         snippet = objectify.fromstring(
-        """<survey optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<survey optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Software development</title>
-             <profile-question type="optional">
+             <profile-question>
                <title>Laptop usage</title>
                <question>Do your employees use laptops?</question>
                <description>&lt;p&gt;Laptops are very common in the modern workplace.&lt;/p&gt;</description>
              </profile-question>
-           </survey>""")
+           </survey>"""  # noqa
+        )
         self.loginAsPortalOwner()
         surveygroup = self.createSurveyGroup()
         importer = upload.SurveyImporter(None)
-        importer.ImportSurvey(snippet, surveygroup, u"Fresh import")
+        survey = importer.ImportSurvey(snippet, surveygroup, u"Fresh import")
         self.assertEqual(surveygroup.keys(), ["fresh-import"])
-        survey = surveygroup["fresh-import"]
         self.assertEqual(survey.keys(), ["1"])
         profile = survey["1"]
-        from euphorie.content.profilequestion import ProfileQuestion
         self.failUnless(isinstance(profile, ProfileQuestion))
         self.assertEqual(profile.title, u"Laptop usage")
 
     def testImportSurvey_ChildOrdering(self):
         snippet = objectify.fromstring(
-        """<survey optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<survey optional="no" xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Software development</title>
              <module optional="no">
                <title>Module one</title>
                <description/>
              </module>
-             <profile-question type="optional">
+             <profile-question>
                <title>Profile one</title>
                <question/>
                <description/>
@@ -503,18 +528,18 @@ class SurveyImporterTests(EuphorieTestCase):
                <title>Module two</title>
                <description/>
              </module>
-             <profile-question type="optional">
+             <profile-question>
                <title>Profile two</title>
                <question/>
                <description/>
              </profile-question>
-           </survey>""")
+           </survey>"""
+        )
         self.loginAsPortalOwner()
         surveygroup = self.createSurveyGroup()
         importer = upload.SurveyImporter(None)
-        importer.ImportSurvey(snippet, surveygroup, u"Fresh import")
+        survey = importer.ImportSurvey(snippet, surveygroup, u"Fresh import")
         self.assertEqual(surveygroup.keys(), ["fresh-import"])
-        survey = surveygroup["fresh-import"]
         self.assertEqual(survey.keys(), ["1", "2", "3", "4"])
         children = survey.values()
         self.assertEquals(children[0].title, u"Module one")
@@ -523,23 +548,24 @@ class SurveyImporterTests(EuphorieTestCase):
         self.assertEquals(children[3].title, u"Profile two")
 
 
-class SectorImporterTests(EuphorieTestCase):
+class SectorImporterTests(EuphorieFunctionalTestCase):
+
     def testImportSurvey(self):
-        from plone.uuid.interfaces import IUUID
         snippet = objectify.fromstring(
-        """<sector xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<sector xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Software development sector</title>
              <survey>
                <title>Software development</title>
              </survey>
-           </sector>""")
+           </sector>"""
+        )
         self.loginAsPortalOwner()
         country = self.portal.sectors.nl
         importer = upload.SectorImporter(country)
         importer(snippet, None, "login", None, u"Import")
         self.assertEqual(
-                country.keys(),
-                ["help", "software-development-sector"])
+            country.keys(), ["help", "software-development-sector"]
+        )
         sector = country["software-development-sector"]
         self.assertEqual(sector.title, "Software development sector")
         self.assertEqual(sector.login, "login")
@@ -555,14 +581,15 @@ class SectorImporterTests(EuphorieTestCase):
 
     def testImportSurvey_WithAccount(self):
         snippet = objectify.fromstring(
-        """<sector xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<sector xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Software development sector</title>
              <account login="coders" password="s3cr3t" />
              <contact>
                <name>Team lead</name>
                <email>discard@simplon.biz</email>
              </contact>
-           </sector>""")
+           </sector>"""
+        )
         self.loginAsPortalOwner()
         country = self.portal.sectors.nl
         importer = upload.SectorImporter(country)
@@ -575,10 +602,11 @@ class SectorImporterTests(EuphorieTestCase):
 
     def testImportSurvey_WithLogo(self):
         snippet = objectify.fromstring(
-        """<sector xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
+            """<sector xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
              <title>Software development sector</title>
              <logo filename="tiny.gif">R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAEALAAAAAABAAEAAAIBTAA7</logo>
-           </sector>""")
+           </sector>"""  # noqa
+        )
         self.loginAsPortalOwner()
         country = self.portal.sectors.nl
         importer = upload.SectorImporter(country)
@@ -587,8 +615,10 @@ class SectorImporterTests(EuphorieTestCase):
         self.assertNotEqual(sector.logo, None)
         self.assertEqual(sector.logo.filename, "tiny.gif")
         self.assertEqual(sector.logo.contentType, "image/gif")
-        self.assertEqual(sector.logo.data, "GIF89a\x01\x00\x01\x00\x80\x00\x00"
-                                           "\x00\x00\x00\xff\xff\xff!\xf9\x04"
-                                           "\x01\x00\x00\x01\x00,\x00\x00\x00"
-                                           "\x00\x01\x00\x01\x00\x00\x02\x01L"
-                                           "\x00;")
+        self.assertEqual(
+            sector.logo.data, "GIF89a\x01\x00\x01\x00\x80\x00\x00"
+            "\x00\x00\x00\xff\xff\xff!\xf9\x04"
+            "\x01\x00\x00\x01\x00,\x00\x00\x00"
+            "\x00\x01\x00\x01\x00\x00\x02\x01L"
+            "\x00;"
+        )
