@@ -1,12 +1,13 @@
-from euphorie.deployment.tests.functional import EuphorieTestCase
+from euphorie.testing import EuphorieFunctionalTestCase
 
-class addCountryGroupingTests(EuphorieTestCase):
+
+class addCountryGroupingTests(EuphorieFunctionalTestCase):
     def addCountryGrouping(self):
         from euphorie.deployment.upgrade.v2 import addCountryGrouping
         addCountryGrouping(self.portal.portal_setup)
 
     def testKeepWrongType(self):
-        self.portal.sectors["nl"].country_type="region"
+        self.portal.sectors["nl"].country_type = "region"
         self.addCountryGrouping()
         self.assertEqual(self.portal.sectors["nl"].country_type, "region")
 
@@ -14,4 +15,3 @@ class addCountryGroupingTests(EuphorieTestCase):
         del self.portal.sectors["nl"].country_type
         self.addCountryGrouping()
         self.assertEqual(self.portal.sectors["nl"].country_type, "eu-member")
-
